@@ -18,6 +18,8 @@ def properSize(fn):
 	return 0 < size and size < (1 << 23)
 
 def getCap(result, limit):
+	if result.cap_html_v2:
+		return (result.cap_html_v2 + ' <a href="%s">source</a>' % result.url).strip()
 	if result.getParseMode() == 'HTML':
 		# currently, the only use case is repost the telegram post
 		# later on, this part might need expansion
